==> huaweicloudsdkgaussdbfornosql-3.1.13-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/optional_flavors_info.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class OptionalFlavorsInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'optional_flavor_list': 'list[ComputeFlavor]',
        'total_count': 'int'
    }

    attribute_map = {
        'optional_flavor_list': 'optional_flavor_list',
        'total_count': 'total_count'
    }

    def __init__(self, optional_flavor_list=None, total_count=None):
        """OptionalFlavorsInfo

        The model defined in huaweicloud sdk

        :param optional_flavor_list: 扩容节点时可用的规格列表。
        :type optional_flavor_list: list[:class:`huaweicloudsdkgaussdbfornosql.v3.ComputeFlavor`]
        :param total_count: 总记录数。
        :type total_count: int
        """
        
        

        self._optional_flavor_list = None
        self._total_count = None
        self.discriminator = None

        if optional_flavor_list is not None:
            self.optional_flavor_list = optional_flavor_list
        if total_count is not None:
            self.total_count = total_count

    @property
    def optional_flavor_list(self):
        """Gets the optional_flavor_list of this OptionalFlavorsInfo.

        扩容节点时可用的规格列表。

        :return: The optional_flavor_list of this OptionalFlavorsInfo.
        :rtype: list[:class:`huaweicloudsdkgaussdbfornosql.v3.ComputeFlavor`]
        """
        return self._optional_flavor_list

    @optional_flavor_list.setter
    def optional_flavor_list(self, optional_flavor_list):
        """Sets the optional_flavor_list of this OptionalFlavorsInfo.

        扩容节点时可用的规格列表。

        :param optional_flavor_list: The optional_flavor_list of this OptionalFlavorsInfo.
        :type optional_flavor_list: list[:class:`huaweicloudsdkgaussdbfornosql.v3.ComputeFlavor`]
        """
        self._optional_flavor_list = optional_flavor_list

    @property
    def total_count(self):
        """Gets the total_count of this OptionalFlavorsInfo.

        总记录数。

        :return: The total_count of this OptionalFlavorsInfo.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this OptionalFlavorsInfo.

        总记录数。

        :param total_count: The total_count of this OptionalFlavorsInfo.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptionalFlavorsInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdbfornosql-3.1.28-py2.py3-none-any.whl: huaweicloudsdkgaussdbfornosql/v3/model/optional_flavors_info.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class OptionalFlavorsInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'list': 'list[ComputeFlavor]',
        'total_count': 'int'
    }

    attribute_map = {
        'list': 'list',
        'total_count': 'total_count'
    }

    def __init__(self, list=None, total_count=None):
        """OptionalFlavorsInfo

        The model defined in huaweicloud sdk

        :param list: 实例规格变更时可用的规格列表。
        :type list: list[:class:`huaweicloudsdkgaussdbfornosql.v3.ComputeFlavor`]
        :param total_count: 总记录数。
        :type total_count: int
        """
        
        

        self._list = None
        self._total_count = None
        self.discriminator = None

        self.list = list
        self.total_count = total_count

    @property
    def list(self):
        """Gets the list of this OptionalFlavorsInfo.

        实例规格变更时可用的规格列表。

        :return: The list of this OptionalFlavorsInfo.
        :rtype: list[:class:`huaweicloudsdkgaussdbfornosql.v3.ComputeFlavor`]
        """
        return self._list

    @list.setter
    def list(self, list):
        """Sets the list of this OptionalFlavorsInfo.

        实例规格变更时可用的规格列表。

        :param list: The list of this OptionalFlavorsInfo.
        :type list: list[:class:`huaweicloudsdkgaussdbfornosql.v3.ComputeFlavor`]
        """
        self._list = list

    @property
    def total_count(self):
        """Gets the total_count of this OptionalFlavorsInfo.

        总记录数。

        :return: The total_count of this OptionalFlavorsInfo.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this OptionalFlavorsInfo.

        总记录数。

        :param total_count: The total_count of this OptionalFlavorsInfo.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptionalFlavorsInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
